CHANGES
=======

0.10.0 (2020-02-06)
-------------------

- Make Python 3 compatible


0.9.0 (2012-11-21)
------------------

- Using Python's ``doctest`` module instead of deprecated
  ``zope.testing.doctest``.

- Removed dependency on ``zope.app.testing`` and ``zope.app.form``.

- Add test extra, move ``zope.testing`` to it.


0.8.1 (2010-05-25)
------------------

- Replaced html entities with unicode entities since they are xthml valid.


0.8.0 (2009-07-23)
------------------

- Updated tests to latest packages.


0.7.0 (2008-05-20)
------------------

- Fixed HTML-encoding of cell contents for ``GetterColumn``.

- Add ``href`` attributes (for MSIE) and fix up JavaScript on Next/Prev links
  for batching.

- Update packaging.

0.6 (2006-09-22)
----------------

Initial release on Cheeseshop.
